# [TestFlows.com Open-Source Software Testing Framework] uExpect

**The uexpect module is still work in progress and is currently under development.
Please use it only for reference.**

Minimal module to provide expect-like capabilities to
launch and control CLI programs.

Currently supports only Python 3.6 or above.

## Installation

```bash
    $ ./build; ./install
```

where

```bash
    $ ./build
```

creates a pip installable package in `./dist`, for example

```bash
    $ ls dist/
    testflows.uexpect-1.2.190905.123636.tar.gz
```

and

```bash
    $ ./install
```

[TestFlows.com Open-Source Software Testing Framework]: https://testflows.com
